import argparse
from direnumerate.__main__ import DirScan, PortScan
from direnumerate.colors import Color
from direnumerate.version import __version__

def dir_scan(args):
    try:
        url = args.url
        wordlist_file = args.wordlist

        enum = DirScan(url, wordlist_file)
        enum.dir_enum()
    except TypeError:
        print(Color.GREEN + "-------------------- Scan Finished --------------------" + Color.RESET)
    except KeyboardInterrupt:
        print(Color.GREEN + "-------------- Attempt interrupted by user ------------" + Color.RESET)

def port_scan(args):
    try:
        host = args.target
        ports = args.ports

        scanner = PortScan(host, ports)
        scanner.scan_ports()
    except KeyboardInterrupt:
        print(Color.GREEN + "-------------- Port scan interrupted by user ------------" + Color.RESET)

def main():
    parser = argparse.ArgumentParser(description="Direnumerate - Directory Enumeration on Web Servers")
    subparsers = parser.add_subparsers(title="subcommands")

    dir_parser = subparsers.add_parser("Ds", help="Perform directory enumeration")
    dir_parser.add_argument("-u", "--url", required=True, help="Target URL (including scheme, e.g. http://www.example.com)")
    dir_parser.add_argument("-w", "--wordlist", required=True, help="Wordlist file")
    dir_parser.set_defaults(func=dir_scan)

    port_parser = subparsers.add_parser("Ps", help="Perform port scanning")
    port_parser.add_argument("-t", "--target", required=True, help="Target host")
    port_parser.add_argument("-p", "--ports", nargs='+', type=int, required=True, help="Ports to scan (e.g., 22 80 443)")
    port_parser.set_defaults(func=port_scan)

    args = parser.parse_args()
    args.func(args)

if __name__ == "__main__":
    main()





def create_wordlist(filename):
    wordlist = [
        "admin",
        "login",
        "images",
        "js",
        "css",
        "config",
        "index",
        "robots.txt",
        "backup",
        "secret",
        "support",
        "contact",
        "blog",
        "forum",
        "product",
        "category",
        "brand",
        "password",
        "123456",
        "qwerty",
        "letmein",
        "access",
        "admin123",
        "administrator",
        "superuser",
        "root",
        "test",
        "guest",
        "demo",
        "webmaster",
        "developer",
        "api",
        "api_key",
        "db",
        "database",
        "user",
        "users",
        "auth",
        "authentication",
        "login.php",
        "wp-admin",
        "wp-login.php",
        "upload",
        "uploads",
        "download",
        "downloads",
        "private",
        "public",
        "static",
        "media",
        "files",
        "file",
        "images/",
        "js/",
        "css/",
        "assets/",
        "images/uploads",
        "userfiles",
        "data",
        "temp",
        "temp/",
        "logs",
        "scripts",
        "web",
        "public_html",
        "secure",
        "private/",
        "backup/",
        "backup_files/",
        "conf",
        "config/",
        "configurations/",
        "install",
        "installer",
        "setup",
        "tmp",
        "db.sql",
        "data.sql",
        "users.sql",
        "passwords.txt",
        "passwd",
        "login.txt",
        "credentials",
        "phpmyadmin",
        "phpMyAdmin",
        "myadmin",
        "myAdmin",
        "panel",
        "control",
        "manager",
        "admin-panel",
        "admin-login",
        "signin",
        "sign-in",
        "login-form",
        "login.html",
        "login.aspx",
        "login.jsp",
        "signin.html",
        "signin.aspx",
        "signin.jsp",
        "register",
        "signup",
        "register.html",
        "register.aspx",
        "signup.html",
        "signup.aspx",
        "forgot-password",
        "forgot-password.html",
        "forgot-password.aspx",
        "reset-password",
        "reset-password.html",
        "reset-password.aspx",
        "contact-us",
        "contact.html",
        "contact.aspx",
        "contact-form",
        "support.html",
        "support.aspx",
        "support-form",
        "about-us",
        "about.html",
        "about.aspx",
        "faq",
        "faq.html",
        "faq.aspx",
        "terms",
        "terms.html",
        "terms.aspx",
        "privacy",
        "privacy.html",
        "privacy.aspx",
        "legal",
        "legal.html",
        "legal.aspx",
        "policy",
        "policy.html",
        "policy.aspx",
        "blog/",
        "news",
        "news.html",
        "news.aspx",
        "articles",
        "articles.html",
        "articles.aspx",
        "events",
        "events.html",
        "events.aspx",
        "products",
        "products.html",
        "products.aspx",
        "services",
        "services.html",
        "services.aspx",
        "portfolio",
        "portfolio.html",
        "portfolio.aspx",
        "gallery",
        "gallery.html",
        "gallery.aspx",
        "download/",
        "downloads/",
        "download-files",
        "download-file",
        "download.html",
        "download.aspx",
        "download.jsp",
        "upload/",
        "uploads/",
        "upload-file",
        "upload.html",
        "upload.aspx",
        "upload.jsp",
        "logout",
        "logout.html",
        "logout.aspx",
        "logout.jsp",
        "signout",
        "signout.html",
        "signout.aspx",
        "signout.jsp",
    ]

    with open(filename, "w") as wordlist_file:
        for word in wordlist:
            wordlist_file.write(word + "\n")


import requests
import socket
import os

from direnumerate.createlist import create_wordlist
from direnumerate.colors import Color


class DirScan():
    def __init__(self, url, wordlist_file):
        self.url = url
        self.wordlist_file = wordlist_file

    def dir_enum(self):
        try:
            with open(self.wordlist_file, "r") as self.wordlist_file:
                for line in self.wordlist_file:
                    path = line.strip()
                    full_url = self.url + "/" + path
                    response = requests.get(full_url)
                    
                    if response.status_code == 200:
                        print(Color.GREEN + f"target access [Found]: -> {Color.RESET + full_url}")
                    elif response.status_code == 204:
                        print(Color.BLUE + f"target access [No Content]: -> {Color.RESET+ full_url}")
                    elif response.status_code == 400:
                        print(Color.YELLOW + f"target access [Bad Request]: -> {Color.RESET+ full_url}")
                    elif response.status_code == 401:
                        print(Color.RED + f"target access [Unauthorized]: -> {Color.RESET+ full_url}")
                    elif response.status_code == 403:
                        print(Color.RED + f"target access [Forbidden]: -> {Color.RESET+ full_url}")
                    elif response.status_code == 404:
                        print(Color.YELLOW + f"target access [Not Found]: -> {Color.RESET+ full_url}")
                    elif response.status_code == 500:
                        print(Color.BLUE + f"target access [Internal Server Error]: -> {Color.RESET+ full_url}")
        except FileNotFoundError:
            if not os.path.isfile(self.wordlist_file):
                create_wordlist(self.wordlist_file)
            print("Word list file not found.")
            
        except TypeError:
            print(Color.GREEN + "-------------------- Scan Finished --------------------" + Color.RESET)
            
        except KeyboardInterrupt:
            print(Color.GREEN + "-------------- attempt interrupted by user ------------" + Color.RESET)

        if not os.path.isfile(self.wordlist_file):
            create_wordlist(self.wordlist_file)


class PortScan:
    def __init__(self, host, ports):
        self.host = host
        self.ports = ports
        self.open_ports = []

    def scan_ports(self):
        for port in self.ports:
            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            sock.settimeout(1)

            result = sock.connect_ex((self.host, port))

            if result == 0:
                self.open_ports.append(port)
                print(Color.GREEN + f"target -> [{self.host}] port: [{port}] is open" + Color.RESET)
            else:
                print(Color.RED + f"target -> [{self.host}] port: [{port}] is closed" + Color.RESET)
            sock.close()




__title__ = "direnumerate"
__author__ = "Juan Bindez"
__license__ = "GPLv2 License"
__js__ = None
__js_url__ = None

import os

from direnumerate.version import __version__
from direnumerate.__main__ import DirScan
from direnumerate.__main__ import PortScan
from direnumerate.createlist import create_wordlist

wordlist_file = "wordlist.txt"

if not os.path.isfile(wordlist_file):
            create_wordlist(wordlist_file)